==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/workflowengine/l10n/uk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Даний оператор недійсний",
    "The given regular expression is invalid" : "Даний регулярний вираз недійсний",
    "The given file size is invalid" : "Даний розмір файлу недійсний",
    "The given tag id is invalid" : "Наданий ідентифікатор тегу недійсний",
    "The given IP range is invalid" : "Даний діапазон IP-адрес недійсний",
    "The given IP range is not valid for IPv4" : "Наведений діапазон IP-адрес недійсний для IPv4",
    "The given IP range is not valid for IPv6" : "Наведений діапазон IP-адрес недійсний для IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "Вказаний час початку недійсний",
    "The given end time is invalid" : "Указаний час завершення недійсний",
    "The given group does not exist" : "Дана група не існує",
    "File" : "Файл",
    "File created" : "Файл створено",
    "File updated" : "Файл оновлено",
    "File renamed" : "Файл перейменовано",
    "File deleted" : "Файл вилучено",
    "File accessed" : "Отримано доступ до файлу",
    "File copied" : "Файл скопійовано",
    "Tag assigned" : "Призначено теґ",
    "Someone" : "Хтось",
    "Operation #%s does not exist" : "Операція №%s не існує",
    "Operation %s does not exist" : "Операція %s не існує",
    "Check %s is invalid" : "Чек %s недійсний",
    "Check #%s does not exist" : "Перевірка №%s не існує",
    "Check %s is invalid or does not exist" : "Чек %s недійсний або не існує",
    "Flow" : "Процеси",
    "Nextcloud workflow engine" : "Керування робочими процесами у Nextcloud",
    "Folder" : "Каталог",
    "Images" : "Зображення",
    "No results" : "Немає результатів",
    "%s (invisible)" : "%s (невидимий)",
    "%s (restricted)" : "%s(обмежено)",
    "Predefined URLs" : "Попередньо визначені URL-адреси",
    "Files WebDAV" : "Файли WebDAV",
    "Android client" : "Клієнт Android",
    "iOS client" : "iOS клієнт",
    "Desktop client" : "Клієнт для ПК",
    "Add new flow" : "Додати новий процес",
    "Cancel" : "Скасувати",
    "Delete" : "Вилучити",
    "Save" : "Зберегти",
    "Available flows" : "Доступні процеси",
    "More flows" : "Більше процесів",
    "Browse the App Store" : "Перегляньте App Store",
    "Configured flows" : "Налаштовані процеси",
    "Your flows" : "Ваші процеси",
    "matches" : "сірники",
    "does not match" : "не відповідає",
    "is" : "є",
    "is not" : "не",
    "File name" : "Ім'я файлу",
    "File size (upload)" : "Розмір файлу (завантаження)",
    "less" : "менше",
    "less or equals" : "менше або дорівнює",
    "greater or equals" : "більше або дорівнює",
    "greater" : "більше",
    "Request remote address" : "Запит віддаленої адреси",
    "matches IPv4" : "відповідає IPv4",
    "does not match IPv4" : "не відповідає IPv4",
    "matches IPv6" : "відповідає IPv6",
    "does not match IPv6" : "не відповідає IPv6",
    "File system tag" : "Тег файлової системи",
    "is tagged with" : "позначено тегом",
    "is not tagged with" : "не позначено тегами",
    "Request URL" : "URL запиту",
    "Request time" : "Час запиту",
    "between" : "між",
    "not between" : "не між",
    "Request user agent" : "Запит агента користувача",
    "User group membership" : "Членство в групі користувачів",
    "is member of" : "є членом",
    "is not member of" : "не є членом"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/workflowengine/l10n/uk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Даний оператор недійсний",
    "The given regular expression is invalid" : "Даний регулярний вираз недійсний",
    "The given file size is invalid" : "Даний розмір файлу недійсний",
    "The given tag id is invalid" : "Наданий ідентифікатор тегу недійсний",
    "The given IP range is invalid" : "Даний діапазон IP-адрес недійсний",
    "The given IP range is not valid for IPv4" : "Наведений діапазон IP-адрес недійсний для IPv4",
    "The given IP range is not valid for IPv6" : "Наведений діапазон IP-адрес недійсний для IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "Вказаний час початку недійсний",
    "The given end time is invalid" : "Указаний час завершення недійсний",
    "The given group does not exist" : "Дана група не існує",
    "File" : "Файл",
    "File created" : "Файл створено",
    "File updated" : "Файл оновлено",
    "File renamed" : "Файл перейменовано",
    "File deleted" : "Файл вилучено",
    "File accessed" : "Отримано доступ до файлу",
    "File copied" : "Файл скопійовано",
    "Tag assigned" : "Призначено теґ",
    "Someone" : "Хтось",
    "Operation #%s does not exist" : "Операція №%s не існує",
    "Operation %s does not exist" : "Операція %s не існує",
    "Check %s does not exist" : "Перевірка %s не існує",
    "Check %s is invalid" : "Чек %s недійсний",
    "Check #%s does not exist" : "Перевірка №%s не існує",
    "Check %s is invalid or does not exist" : "Чек %s недійсний або не існує",
    "Flow" : "Процеси",
    "Nextcloud workflow engine" : "Керування робочими процесами у Nextcloud",
    "Folder" : "Каталог",
    "Images" : "Зображення",
    "Predefined URLs" : "Попередньо визначені URL-адреси",
    "Files WebDAV" : "Файли WebDAV",
    "Android client" : "Клієнт Android",
    "iOS client" : "iOS клієнт",
    "Desktop client" : "Клієнт для ПК",
    "Add new flow" : "Додати новий процес",
    "Cancel" : "Скасувати",
    "Delete" : "Вилучити",
    "Save" : "Зберегти",
    "Available flows" : "Доступні процеси",
    "More flows" : "Більше процесів",
    "Browse the App Store" : "Перегляньте App Store",
    "Configured flows" : "Налаштовані процеси",
    "Your flows" : "Ваші процеси",
    "matches" : "сірники",
    "does not match" : "не відповідає",
    "is" : "є",
    "is not" : "не",
    "File name" : "Ім'я файлу",
    "File size (upload)" : "Розмір файлу (завантаження)",
    "less" : "менше",
    "less or equals" : "менше або дорівнює",
    "greater or equals" : "більше або дорівнює",
    "greater" : "більше",
    "Request remote address" : "Запит віддаленої адреси",
    "matches IPv4" : "відповідає IPv4",
    "does not match IPv4" : "не відповідає IPv4",
    "matches IPv6" : "відповідає IPv6",
    "does not match IPv6" : "не відповідає IPv6",
    "File system tag" : "Тег файлової системи",
    "is tagged with" : "позначено тегом",
    "is not tagged with" : "не позначено тегами",
    "Request URL" : "URL запиту",
    "Request time" : "Час запиту",
    "between" : "між",
    "not between" : "не між",
    "Request user agent" : "Запит агента користувача",
    "User group membership" : "Участь користувача в групі",
    "is member of" : "є учасником",
    "is not member of" : "не є учасником",
    "No results" : "Немає результатів",
    "%s (invisible)" : "%s (невидимий)",
    "%s (restricted)" : "%s(обмежено)"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
